*==============================================================================*
*                             Description of dofile                            *
/*=============================================================================*

This dofile generates Table 1 through Table 6, Table A2 through Table A4, and Figures 1 and 2
that are presented in the article "Management Gender Composition and the Gender Pay Gap: 
Evidence from British Panel Data". 
The structure of this dofile is as follows: 
  
  1. Opening data
  2. Summary statistics (Table 1, Table 2, Table 3, Table 4, Table A2, Table A3, Table A4) 
  3. Management gender composition and the gender earnings gap (Table 5, Figure 1)
  4. Management gender composition and workplace policies (Table 6)
  5. Additional analyses (Figure 2)
 
*==============================================================================*/
*    	   	  	                1. Opening data                                *
*==============================================================================*

cap log close
log using "$pathl/analysis.log", replace
use "$pathp/workingdata.dta", clear

*==============================================================================*
*                             2. Summary statistics                            *
*==============================================================================*

/*Table 1. Summary Statistics and Coding of Workplace-level Variables*/

foreach var of varlist industry legalstatus workplaceage etenure etraining eage eedu {
		tab `var', gen(`var'a)
}
egen pickone=tag(serno nyear)

estpost sum nfmprop zallemps nfemprop nmgrprop industrya? industrya10 industrya11 ///
		industrya12 legalstatusa? nforeign workplaceagea? if pickone==1
esttab using "$patht\Table 1.rtf", cells ("mean(fmt(2)) sd min(fmt(0)) max(fmt(0))") ///
		l title("Table 1. Summary Statistics and Coding of Workplace-level Variables") ///
		addnotes("Note: WERS 2004-2011, own calculations.") replace
		/*note: due to an error in "tab x, gen(x)" above, industrya? stops at 
		industrya9, hence I add ind10 thru ind12 separately*/

/*Table 2. Summary Statistics and Coding of Employee-level Variables*/

estpost sum ewage efemale ehours etenurea? etraininga? ecommit eunion eagea? epartner echildren eedua? 
esttab using "$patht\Table 2.rtf", cells ("mean(fmt(2)) sd min(fmt(0)) max(fmt(0))") ///
		l title("Table 2. Summary Statistics and Coding of Employee-level Variables") ///
		addnotes("Note: WERS 2004-2011, own calculations.") replace

/*Table 3. Summary Statistics and Coding of Workplace Policies and Arrangements*/

estpost sum ndivstra nspecwom niprac11 niprac21 niprac31 niprac41 niprac51 ///
		nffhome nffflexi nffjshar nffredhr nffcompr nffterm nnursery nccsubsi ///
		equaldiv flex care nequal nflex ncare if pickone==1
esttab using "$patht\Table 3.rtf", cells ("mean(fmt(2)) sd min(fmt(0)) max(fmt(0))") ///
		l title("Table 3. Summary Statistics and Coding of Workplace Policies and Arrangements") ///
		addnotes("Note: WERS 2004-2011, own calculations.") replace

/*Table A2. Summary Statistics of Workplace-level Variables by Share of Female Managers*/

tabstat zallemps nfemprop nmgrprop industrya? industrya10 industrya11 ///
		industrya12 legalstatusa? nforeign workplaceagea? if pickone==1, ///
		by(nfmprop6) stats(mean sd count) col(stat) format(%9.2f) 
	
/*Table A3. Summary Statistics of Employee-level Variables by Employee Gender*/

tabstat ewage ehours etenurea? etraininga? ecommit eunion eagea? epartner echildren eedua?, ///
		by(efemale) stats(mean sd count) col(stat) format(%9.2f) 

** -- Workplace-level changes 2004-2011 -- **

* defining as panel data
keep if pickone==1
xtset c time 

/*Table 4. Share Female Managers 2004-2011*/

tab nfmprop6 nyear, nofreq column //Panel A: Main Development
generate lnfmprop6 = L.nfmprop6
tab lnfmprop6 nfmprop6 if time == 1, nofreq row //Panel B: 2004-2011 Changes

/*Table A4. Workplace-level Changes in Policies and Arrangements 2004-2011*/

*% workplaces that implemented/abolished policy 2004-11 (columns 4 and 5)
//the following lines of code produce the numbers on which the percentages are based
foreach var of varlist ndivstra nspecwom niprac11 niprac21 niprac31 niprac41 niprac51 nffhome ///
		nffflexi nffjshar nffredhr nffcompr nffterm nnursery nccsubsi equaldiv flex care {
		generate l`var' = L.`var'
		tab l`var' `var' if time == 1
}

*% workplaces with policy in 2004/2011 (columns 1 and 2) 
foreach var of varlist ndivstra nspecwom niprac11 niprac21 niprac31 niprac41 niprac51 nffhome nffflexi ///
		nffjshar nffredhr nffcompr nffterm nnursery nccsubsi equaldiv flex care nequal nflex ncare {
		bysort nyear: sum `var'
}

*% workplaces that changed policy 2004-11 (column 3) 
//keeping only relevant variables for better overview of dataset
keep serno nyear nfmprop ndivstra nspecwom niprac11 niprac21 niprac31 niprac41 ///
		niprac51 nffhome nffflexi nffjshar nffredhr nffcompr nffterm nnursery ///
		nccsubsi equaldiv flex care nequal nflex ncare paysystem

//reshaping long to wide
reshape wide nfmprop ndivstra nspecwom niprac11 niprac21 niprac31 niprac41 ///
		niprac51 nffhome nffflexi nffjshar nffredhr nffcompr nffterm nnursery ///
		nccsubsi equaldiv flex care nequal nflex ncare paysystem, j(nyear) i(serno)

//% workplaces that changed policy 2004-11 (column 3)
foreach x of newlist ndivstra nspecwom niprac11 niprac21 niprac31 niprac41 niprac51 nffhome nffflexi ///
		nffjshar nffredhr nffcompr nffterm nnursery nccsubsi equaldiv flex care nequal nflex ncare {
		gen `x'p=0
		replace `x'p=1 if `x'0!=`x'1
		fre `x'p 
}

use "$pathp/workingdata.dta", clear //reopening file to load complete data

*==============================================================================*
*    	  3. Management gender composition and the gender earnings gap         *
*==============================================================================*

/*Table 5. Workplace-fixed Time-fixed Effects Models; Dependent variable: weekly wage*/

xtreg ewage efemale nfmprop efemale#c.nfmprop time, fe i(serno) 
eststo m1 //Model 1 (includes only predictors of interest)
xtreg ewage efemale nfmprop efemale#c.nfmprop time ehours i.etenure i.etraining ///
		ecommit eunion i.eage epartner echildren i.eedu, fe i(serno) 
		eststo m2 //Model 2 (adds the employee-level controls)
		lrtest m1 m2
xtreg ewage efemale nfmprop efemale#c.nfmprop time ehours i.etenure i.etraining ///
		ecommit eunion i.eage epartner echildren i.eedu lnzallemps nfemprop ///
		nmgrprop i.industry i.legalstatus nforeign i.workplaceage, fe i(serno) 
		eststo m3 //Model 3 (adds the workplace-level controls)
		lrtest m2 m3
esttab m1 m2 m3 ///
		using "$patht\Table 5.rtf", star(* 0.05 ** 0.01 *** 0.001) ///
		keep (_cons efemale nfmprop 1.efemale#c.nfmprop time) order(efemale nfmprop 1.efemale#c.nfmprop time _cons) ///
		varlabels(_cons "Constant" efemale "Female" nfmprop "Female managers" 1.efemale#c.nfmprop "Female x Female managers" time "Year") ///
		title("Table 5. Workplace-fixed Time-fixed Effects Models; Dependent variable: weekly wage") ///
		se scalars("ll Log lik.") ar2(4) obslast addnotes("Note: WERS 2004-2011, own calculations") replace
			
/*Figure 1. Predicted average weekly earnings for women and men*/
			
xtreg ewage i.efemale nfmprop i.efemale#c.nfmprop time ehours i.etenure i.etraining ///
		ecommit eunion i.eage epartner echildren i.eedu lnzallemps nfemprop nmgrprop ///
		i.industry i.legalstatus nforeign i.workplaceage, fe i(serno)
margins i.efemale, at(nfmprop=(0(10)100)) 
marginsplot, ///
		plot1opts(msymbol(D) mcolor(black) lcolor(black) lpattern(solid)) ///
		plot2opts(msymbol(T) mcolor(black) lcolor(black) lpattern(shortdash)) ///
		title ("") ///
		ytitle("Weekly Earnings (£)", size(small)) ///
		ylab (290 (10) 390, labsize(small) angle(0))	///
		xtitle("Percentage Point Increase in % Female Managers", size(small)) ///
		xscale(titlegap(2)) xlab (, labsize(small)) ///
		legend(ring(0) position(1) rows(2) lwidth(vvthin) size(small)) ///
		graphregion(color(white) fcolor(white) icolor(white)) ///
		ci1opts(fintensity(30) color(gs10)) ///
		ci2opts(fintensity(30) color(gs10))
		graph export "$pathf/Figure 1.pdf", replace
eststo drop *

*==============================================================================*
*    	     4. Management gender composition and workplace policies           *
*==============================================================================*

** -- Mediated moderation analysis per workplace policy -- ** 

/*Evidence for mediated moderation is found if the following conditions are satisfied:
Eq 1:   c.nfmprop#i.efemale on ewage is significant 
Eg 2&3: nfmprop on policy (Eq 2) is sig and i.policy#i.efemale on ewage (Eq 3) is sig;	
		this would mean that, in Eq 3,
Eq 3:   the moderation of the residual direct effect of the treatment should be 
        reduced compared to the moderation of the overall treatment, that is, 
        c.nfmprop#i.efemale in Eq 3 should be smaller in absolute value than 
        c.nfmprop#i.efemale in Eq 1
*/

**equation 1 is already run above in section 4 

**equation 2
foreach var of varlist ndivstra nspecwom niprac41 nffhome nffflexi nffjshar ///
		nffredhr nffcompr nccsubsi equaldiv care {
		xtlogit `var' nfmprop time lnzallemps nfemprop nmgrprop i.industry ///
		i.legalstatus nforeign i.workplaceage, fe i(serno)
}

/*count variables*/
foreach var of varlist nequal nflex ncare {
		xtpoisson `var' nfmprop time lnzallemps nfemprop nmgrprop i.industry ///
		i.legalstatus nforeign i.workplaceage, fe i(serno)
}

/*these models don't contain the variable 'industry' because they would not converge with it included;
since these are workplace-fixed effects, however, and since only very few workplaces changed industry
between the two waves, the results are likely not affected by this omission */
foreach var of varlist niprac11 niprac21 niprac31 niprac51 nffterm flex {
		xtlogit `var' nfmprop time lnzallemps nfemprop nmgrprop i.legalstatus nforeign i.workplaceage, fe i(serno)
}
	
/*this model does not contain the variables 'industry', 'legalstatus' and 'workplaceage'
because it would not converge with them included;
since this is workplace-fixed effects, however, and since only very few workplaces changed industry and legal status
between the two waves, the results are not likely to be affected much by this omission */
xtlogit nnursery nfmprop time lnzallemps nfemprop nmgrprop nforeign, fe i(serno) 

**equation 3
foreach var of varlist ndivstra nspecwom niprac11 niprac21 niprac31 niprac41 niprac51 ///
		nffhome nffflexi nffjshar nffredhr nffcompr nffterm nnursery nccsubsi equaldiv flex care {
		xtreg ewage nfmprop efemale c.nfmprop#efemale `var' `var'#efemale ///
		time ehours i.etenure i.etraining ecommit eunion i.eage epartner echildren i.eedu ///
		lnzallemps nfemprop nmgrprop i.industry i.legalstatus nforeign i.workplaceage, fe i(serno)
}

/*count variables*/
foreach var of varlist nequal nflex ncare {
		xtreg ewage nfmprop efemale c.nfmprop#efemale `var' c.`var'#efemale ///
		time ehours i.etenure i.etraining ecommit eunion i.eage epartner echildren i.eedu ///
		lnzallemps nfemprop nmgrprop i.industry i.legalstatus nforeign i.workplaceage, fe i(serno)
}

/*conclusion: mediated moderation conditions satisfied only for home-based working 
and reviewing of recruitment for gender discrimination*/
	
/*Table 6. Home-based working & Review of recruitment for gender discrimination; Dependent variable: weekly wage*/
xtreg ewage efemale nfmprop efemale#c.nfmprop time ehours i.etenure i.etraining ///
		ecommit eunion i.eage epartner echildren i.eedu lnzallemps nfemprop ///
		nmgrprop i.industry i.legalstatus nforeign i.workplaceage, fe i(serno) 
		eststo m1 //Eq 1
xtreg ewage nfmprop efemale c.nfmprop#efemale nffhome nffhome#efemale ///
		time ehours i.etenure i.etraining ecommit eunion i.eage epartner echildren i.eedu ///
		lnzallemps nfemprop nmgrprop i.industry i.legalstatus nforeign i.workplaceage, fe i(serno) 
		eststo m2 //Eq 3 home-based working
xtreg ewage nfmprop efemale c.nfmprop#efemale niprac21 niprac21#efemale ///
		time ehours i.etenure i.etraining ecommit eunion i.eage epartner echildren i.eedu ///
		lnzallemps nfemprop nmgrprop i.industry i.legalstatus nforeign i.workplaceage, fe i(serno) 
		eststo m3 //Eq 3 reviews recr gender
esttab m1 m2 m3 ///
		using "$patht\Table 6.rtf", star(* 0.05 ** 0.01 *** 0.001) ///
		keep(_cons efemale nfmprop 1.efemale#c.nfmprop time nffhome 0.nffhome#1.efemale niprac21 0.niprac21#1.efemale) ///
		order(efemale nfmprop 1.efemale#c.nfmprop nffhome 0.nffhome#1.efemale niprac21 0.niprac21#1.efemale time _cons) ///
		varlabels(_cons "Constant" efemale "Female" nfmprop "Female managers" 1.efemale#c.nfmprop "Female x Female managers" time "Year" ///
		nffhome "Home-based working" 0.nffhome#1.efemale "Home-based working x Female" niprac21 "Reviews recruitment for gender discrimination" ///
		0.niprac21#1.efemale "Reviews recruitment for gender discrimination x Female") ///
		title("Table 6. Home-based working & Review of recruitment for gender discrimination; Dependent variable: weekly wage") ///
		se scalars("ll Log lik.") ar2(4) obslast addnotes("Note: WERS 2004-2011, own calculations") replace
eststo drop *
			
*===============================================================================*
*                              5. Additional analyses                           *
*===============================================================================*
		
/*Figure 2. Predicted average weekly earnings for women and men by pay system*/

gen pay2 = paysystem if nyear==0
sort serno nyear
bys serno: gen sys=pay2[_n-1]
bys serno nyear: egen max_sys=max(sys) //variable indicating paysystem in 2004

foreach num of numlist 1/5 7{
	xtreg ewage i.efemale nfmprop i.efemale#c.nfmprop time ehours i.etenure i.etraining ///
		ecommit eunion i.eage epartner echildren i.eedu lnzallemps nfemprop nmgrprop ///
		i.industry i.legalstatus nforeign i.workplaceage if max_sys==`num', fe i(serno) 
	margins i.efemale, at(nfmprop=(0(10)100)) post
	marginsplot, ///
		plot1opts(msymbol(D) mcolor(black) lcolor(black) lpattern(solid)) ///
		plot2opts(msymbol(T) mcolor(black) lcolor(black) lpattern(shortdash)) ///
		title ("title`num'", size(small)) ///
		ytitle("Weekly Earnings (£)", size(small)) ///
		ylab (120 (20) 500, labsize(small) angle(0))	///
		xtitle("Percentage Point Increase in % Female Managers", size(small)) ///
		xscale(titlegap(2)) xlab (, labsize(small)) ///
		legend(ring(0) position(1) rows(2) lwidth(vvthin) size(small)) ///
		graphregion(color(white) fcolor(white) icolor(white)) ///
		ci1opts(fintensity(30) color(gs10)) ///
		ci2opts(fintensity(30) color(gs10))
	graph save "$pathf/fig2`num'.gph", replace
}

graph combine 	"$pathf/fig21.gph" ///
				"$pathf/fig22.gph" ///
				"$pathf/fig23.gph" ///
				"$pathf/fig24.gph" ///
				"$pathf/fig25.gph" ///
				"$pathf/fig27.gph", ///
				xsize(6) ysize(6) graphregion(fcolor(white)) iscale(0.4) rows(2)
graph save "$pathf/Figure 2.gph", replace	
gr_edit .plotregion1.graph1.title.text = {}
gr_edit .plotregion1.graph1.title.text.Arrpush Industry-wide agreement
gr_edit .plotregion1.graph2.title.text = {}
gr_edit .plotregion1.graph2.title.text.Arrpush Collective bargaining at an organisation level
gr_edit .plotregion1.graph3.title.text = {}
gr_edit .plotregion1.graph3.title.text.Arrpush Collective bargaining at this workplace
gr_edit .plotregion1.graph4.title.text = {}
gr_edit .plotregion1.graph4.title.text.Arrpush Set by management at a higher level in this organisation
gr_edit .plotregion1.graph5.title.text = {}
gr_edit .plotregion1.graph5.title.text.Arrpush Set by management at this workplace
gr_edit .plotregion1.graph6.title.text = {}
gr_edit .plotregion1.graph6.title.text.Arrpush Independent pay review body
graph export "$pathf/Figure 2.pdf", replace
				
** -- Is the effect of management gender composition linear? -- ** 

//model without splines
xtreg ewage efemale nfmprop time ehours i.etenure i.etraining ecommit eunion ///
		i.eage epartner echildren i.eedu lnzallemps nfemprop nmgrprop i.industry ///
		i.legalstatus nforeign i.workplaceage i.efemale#c.nfmprop, fe i(serno) 
		estat ic 

//linear splines at 10, 25, 50, 60, 75, 90
foreach num of numlist 10 25 50 60 75 90 {
	preserve
	mkspline nfmprop1 `num' nfmprop2=nfmprop, marginal
	xtreg ewage i.efemale nfmprop nfmprop2 time ehours i.etenure i.etraining ecommit eunion ///
		i.eage epartner echildren i.eedu lnzallemps nfemprop nmgrprop i.industry ///
		i.legalstatus nforeign i.workplaceage i.efemale#c.nfmprop i.efemale#c.nfmprop2, fe i(serno) 
	estat ic
	restore
}

//quadratic term 
preserve
gen nfmprop2=nfmprop*nfmprop
xtreg ewage efemale nfmprop nfmprop2 time ehours i.etenure i.etraining ecommit eunion ///
		i.eage epartner echildren i.eedu lnzallemps nfemprop nmgrprop i.industry ///
		i.legalstatus nforeign i.workplaceage i.efemale#c.nfmprop i.efemale#c.nfmprop2, fe i(serno)
estat ic 
restore	 

//with categories: 0, 1/9, 10-24, 25-49, 50, 51-74, 75-100 
preserve
recode nfmprop 0=1 1/9=2 10/24=3 25/49=4 50=5 51/74=6 75/100=7, gen(nfmprop_cat)
xtreg ewage efemale i.nfmprop_cat time ehours i.etenure i.etraining ecommit eunion ///
		i.eage epartner echildren i.eedu lnzallemps nfemprop nmgrprop i.industry ///
		i.legalstatus nforeign i.workplaceage i.efemale#i.nfmprop_cat, fe i(serno) 
estat ic 
restore

/*the model without splines has the lowest AIC and BIC, hence best model fit*/

** -- Distribution earnings -- ** 
hist ewage
hist lnewage
//non-logged earnings less skewed than logged earnings in analytic sample

//excluding the (a) 2 and (b) 4 highest earnings values 
foreach num of numlist 914 742 {
	hist ewage if ewage<`num' 
	xtreg ewage efemale nfmprop efemale#c.nfmprop time ehours i.etenure i.etraining ///
		ecommit eunion i.eage epartner echildren i.eedu lnzallemps nfemprop nmgrprop ///
		i.industry i.legalstatus nforeign i.workplaceage if ewage<`num', fe i(serno)
} 
/*in both cases, the effect of the share of women in management on the gender
earnings gap decreases in magnitude but remains substantial*/

** -- Hourly earnings -- ** 
fre ehours
gen hwage=ewage/ehours
hist hwage //heavily skewed
gen lnhwage=ln(hwage) //taking natural log of hourly earnings 
lab var lnhwage "natural logarithm hourly wage"
hist lnhwage
//dropping top and bottom 1% 
sum lnhwage, de
gen lnhwage_trim = lnhwage if lnhwage >= r(p1) & lnhwage <=r(p99)
hist lnhwage_trim

xtreg lnhwage_trim efemale nfmprop efemale#c.nfmprop time i.etenure i.etraining ///
		ecommit eunion i.eage epartner echildren i.eedu lnzallemps nfemprop nmgrprop ///
		i.industry i.legalstatus nforeign i.workplaceage, fe i(serno) 
		
** -- Addressing skew of distribution of share female managers  -- ** 

//excluding workplaces with (a) 0%, (b) 50% and (c) 100% female managers
foreach num of numlist 0 50 100 {
	preserve 
	drop if nfmprop==`num'
	hist nfmprop
	xtreg ewage efemale nfmprop time ehours i.etenure i.etraining ecommit eunion ///
		i.eage epartner echildren i.eedu lnzallemps nfemprop nmgrprop i.industry ///
		i.legalstatus nforeign i.workplaceage i.efemale#c.nfmprop, fe i(serno) 
	restore 
} 		//no substantive differences

//excluding workplaces with 0% and 100% female managers
preserve 
drop if nfmprop==0 | nfmprop==100
hist nfmprop
xtreg ewage efemale nfmprop time ehours i.etenure i.etraining ecommit eunion ///
		i.eage epartner echildren i.eedu lnzallemps nfemprop nmgrprop i.industry ///
		i.legalstatus nforeign i.workplaceage i.efemale#c.nfmprop, fe i(serno) 
restore //no substantive differences

//excluding workplaces with 0%, 50% and 100% female managers 
preserve 
drop if nfmprop==0 | nfmprop==50 | nfmprop==100
hist nfmprop
xtreg ewage efemale nfmprop time ehours i.etenure i.etraining ecommit eunion ///
		i.eage epartner echildren i.eedu lnzallemps nfemprop nmgrprop i.industry ///
		i.legalstatus nforeign i.workplaceage i.efemale#c.nfmprop, fe i(serno) 
restore //no substantive differences

** -- Addressing skew of distribution of share managers  -- ** 

xtreg ewage efemale nfmprop efemale#c.nfmprop time ehours i.etenure i.etraining ///
		ecommit eunion i.eage epartner echildren i.eedu lnzallemps nfemprop lnnmgrprop ///
		i.industry i.legalstatus nforeign i.workplaceage, fe i(serno) //no substantive differences

** -- Clustered and robust standard errors  -- ** 
xtreg ewage efemale nfmprop efemale#c.nfmprop time ehours i.etenure i.etraining ///
		ecommit eunion i.eage epartner echildren i.eedu lnzallemps nfemprop nmgrprop ///
		i.industry i.legalstatus nforeign i.workplaceage, fe i(serno) vce(cluster serno)
//standard errors increase but results remain statistically significant

xtreg ewage efemale nfmprop efemale#c.nfmprop time ehours i.etenure i.etraining ///
		ecommit eunion i.eage epartner echildren i.eedu lnzallemps nfemprop nmgrprop ///
		i.industry i.legalstatus nforeign i.workplaceage, fe i(serno) vce(robust)
//identical results to those with clustered se

** -- Regression diagnostics  -- **

xtreg ewage efemale nfmprop efemale#c.nfmprop time ehours i.etenure i.etraining ///
		ecommit eunion i.eage epartner echildren i.eedu lnzallemps nfemprop nmgrprop ///
		i.industry i.legalstatus nforeign i.workplaceage, fe i(serno)  
predict double residual_e, e
predict double fitted, xb

*normality of residuals
kdensity residual_e, normal name(g1, replace) 
graph box residual_e, name(g2, replace) 
qnorm residual_e, name(g3, replace) /*plots the quantiles of a variable against the quantiles 
of a normal distribution; sensitive to non-normality near the tails.*/
pnorm residual_e, name(g4, replace) /*graphs a standardized normal probability (P-P) plot;
sensitive to non-normality in the middle range of data*/
graph combine g1 g2 g3 g4, name(gcomb2, replace)

*homoscedasticity
scatter residual_e fit, yline(0)
//analysis rerun with robust standard errors above

*multicolinearity
reg ewage efemale nfmprop time ehours i.etenure i.etraining ecommit eunion i.eage epartner ///
		echildren i.eedu lnzallemps nfemprop nmgrprop i.industry i.legalstatus nforeign i.workplaceage
estat vif

** -- Multiple imputation of missings  -- ** 

use "$pathd/mq&seq&wrq_derived.dta", clear

//creating variables for imputation
recode e15  1=25 2=65 3=95 4=125 5=160 6=200 7=240 8=285 9=335 10=395 11=485  ///
		    12=610 13=775 14=971, gen(wage2004) 
recode qe11 1=24 2=63 3=91 4=119 5=155 6=191 7=226 8=270 9=318 10=377 11=464 12=583 ///
		    13=742 14=914, gen(wage2011) 
generate ewage=wage2011 if nyear==1
replace ewage=wage2004 if nyear==0 & wage2011==.
recode ewage .a=. .c=. .e=. 
recode qe1 (1=0 "Men") (2=1 "Women") (.a=.) (.c=.) (.e=.), gen(efemale)
gen zmgr_fem2004=zmng_fft+zmng_fpt 
replace zmgr_fem=zmgr_fem2004 if nyear==0 & zmgr_fem==. 
recode zmgr_fem .b=. .e=.
replace nfmprop=int(nfmprop*100)
recode nfmprop .a=. .b=. .e=. 
replace zallemps=ZALLEMPS if nyear==0 & missing(zallemps) 
gen lnzallemps=ln(zallemps) 
drop nfemprop 
gen ztotwom04=ZFEMFULL+ZFEMPRT 
replace ztotwom=ztotwom04 if nyear==0 & missing(ztotwom) 
gen float nfemprop=.
replace nfemprop=ztotwom/zallemps
replace nfemprop=.b if ztotwom==.b
replace nfemprop=.e if ztotwom==.e
replace nfemprop=.e if zallemps==.e
replace nfemprop=int(100*nfemprop) 
drop nmgrprop 
gen float nmgrprop=.
replace nmgrprop=zmgr_tot/zallemps if nyear==1
replace nmgrprop=zmng_tot/zallemps if nyear==0
replace nmgrprop=.b if zmgr_tot==.b | zmng_tot==.b
replace nmgrprop=.e if zmgr_tot==.e | zallemps==.e
replace nmgrprop=int(100*nmgrprop) 
recode nsicod03 .e=., gen(industry)
drop nstatus5 
replace astatus1=ASTATUS1 if nyear==0 & missing(astatus1)
recode astatus1 (1=1 "Public limited company") (2=2 "Private limited company") ///
		(3/8=3 "Other trading sector") (12=4 "Local/central govt") ///
		(9/11=5 "Other public sector") (.e=.), gen(legalstatus)
drop nprivate 
replace astatus2=ASTATUS2 if nyear==0 & missing(astatus2) 
gen byte nprivate=1 if (astatus1>0 & astatus1<8) & ((astatus2>0 & astatus2<8)|astatus2>=.)
replace nprivate=0 if (astatus1>7 & astatus1<=12) & ((astatus2>7 & astatus2<=12)|astatus2>=.)
replace nprivate=.e if nprivate==. & astatus1==.e
drop nforeign 
tab acontrol nyear, m
replace acontrol=ACONTROL if nyear==0 & missing(acontrol) 
recode acontrol 4/5=1 1/3=0 .a=. .b=. .e=., ge(nforeign)
replace nforeign=0 if nprivate==0
replace ahowlong=AHOWLONG if nyear==0 & missing(ahowlong) 
replace ahowest=AHOWEST if nyear==0 & missing(ahowest) 
drop nage1 nage2 
recode ahowlong (0/4=1 "Less than 5 years") (5/9=2 "5 to 9 years") (10/14=3 "10 to 14 years") (15/20=4 "15 to 20 years") (21/24=5 "21 to 24 years") (25/999=6 "25 or more years") (.b=.b "Don't know"), ge(nage1)
replace nage1=ahowest if ahowlong==.b
recode nage1 (1=1 "Less than 5 years") (2=2 "5 to 9 years") (3/5=3 "10 to 24 years") (6=4 "25 or more years") (.b=.), ge(workplaceage)
replace ehours=80 if ehours>80 & !missing(ehours) 
recode ehours .a=. .e=.
recode qa1 .a=. .c=., gen(etenure)
recode qb3 .a=. .c=. .e=., gen(etraining)
recode ecommit .m=.
recode emember .a=. .c=., gen(eunion)
recode eage .a=. 
recode qe3 (2=1 "yes") (1 3/4=0 "no"), gen(epartner)
recode e3 4=1 1/3=0, gen(par2)
replace epartner=par2 if nyear==0 & missing(epartner)
recode epartner .a=. .c=. .e=.
recode eanydepc .a=. .e=., gen(echildren)
recode ehiacar .a=. 0=1 1=2 2=3 3=4 4=5 5=6 6=7 7=8, gen(eedu)
recode esocoldb .b=. .e=., gen(emng)
recode nyear 2004=0 2011=1, gen(time) 

//selection panel
keep if nseqpan==1 

//excluding "Managers, Directors and Senior officials" 
drop if emng==1 

//keeping relevant variables 
keep serno time ewage efemale nfmprop lnzallemps nfemprop nmgrprop ///
		industry legalstatus nforeign workplaceage ehours etenure etraining ///
		ecommit eunion eage epartner echildren eedu 

//imputation 

*declaring the data as mi data
mi set wide
mi xtset serno

*number of missing observations per variable	
mi misstable sum

*checking missing data pattern 
mi misstable nested //largely arbitrary

*registering variables
mi register imputed ewage efemale nfmprop nfemprop nmgrprop nforeign workplaceage ///
		ehours etenure etraining ecommit eunion eage epartner echildren eedu //imputed vars 
mi register regular time lnzallemps legalstatus industry //regular vars that have the same values in all m

*imputation
mi impute chained (pmm, knn(5)) ewage nfmprop nfemprop nmgrprop ehours ecommit ///
		(logit) efemale nforeign eunion epartner echildren ///
		(mlogit, augment) workplaceage etenure etraining eage eedu ///
		= time lnzallemps legalstatus industry, add(20) rseed(2232) dots force replace 
		//20 imputations

//saving imputed data
save "$pathp/imputeddata.dta", replace //saving imputed data for analysis	

//analysis
mi estimate: xtreg ewage efemale nfmprop efemale#c.nfmprop time ehours i.etenure i.etraining ///
		ecommit eunion i.eage epartner echildren i.eedu lnzallemps nfemprop nmgrprop ///
		i.industry i.legalstatus nforeign i.workplaceage, fe i(serno) 
		/*no substantive differences with listwise deletion of missings*/

**end dofile
log close
