*==============================================================================*
*                            Description of dofile                             *
/*=============================================================================*

This dofile prepares the data for the results that are presented in the article 
"Management Gender Composition and the Gender Pay Gap: Evidence from British Panel Data". 
The structure of this dofile is as follows: 

  1. Opening data 
  2. Data preparation
  3. Analytic sample (Table A1)
  4. Saving data
 
*==============================================================================*/
*    	   	  	                1. Opening data                                *
*==============================================================================*

cap log close
log using "$pathl/dataprep.log", replace
use "$pathd/mq&seq&wrq_derived.dta", clear

/* Data: Workplace Employment Relations Study (WERS) 2011
Retrieved from: https://www.gov.uk/government/publications/the-2011-workplace-employment-relations-study-wers, May 2016
Note that mq&seq&wrq_derived.dta is a dataset combining the data from WERS 2011 and 2004 that I constructed myself 
using do-files provided by the WERS research team. Running the 'master.do' file produces mq&seq&wrq_derived.dta */

* workplace, employee, and wave identifiers
generate c=serno //workplace
generate id=persid //employee
recode nyear 2004=0 2011=1, gen(time) //wave

*==============================================================================*
*    	   	  	                2. Data preparation                            *
*==============================================================================*

** -- A. Outcome variable -- **
/* e11. How much do you get paid for your job here, before tax and other deductions
are taken out? If your pay before tax changes from week to week before of overtime,
or because you work different hours each week, think about what you earn on average. 
-E15 in WERS 2004; question is same but categories are different because of inflation. */

* - taking midpoints of the income categories to create continuous variables - *

*2004
tab e15, m
display 50/2 //25
display (51+80)/2 //65
display (81+110)/2 //95
display (111+140)/2 //125
display (141+180)/2 //160
display (181+220)/2 //200
display (221+260)/2 //240
display (261+310)/2 //285
display (311+360)/2 //335
display (361+430)/2 //395
display (431+540)/2 //485
display (541+680)/2 //610
display (681+870)/2 //775
//last category is "871 or more per week"

/* three alternative ways of choosing the top value, as suggested by "Hout, M. (2004). 
Getting the most out of the GSS income measures. Washington: National Opinion Research Center":
1. topcode the last category by adding a fixed value, say 100 --> 971 
2. add 30% to the lower limit of the top category
3. extrapolate from the next-to-last category's midpoint using a formula based on the Pareto curve.
Of the three options, the first one seems most fitting; option 2 yields too high of a value,
and option 3 yields a value lower than than the lower limit (see in what follows). */

display (871*0.3)+ 871 //option 2 --> 1132 
display ln(1083+1013)-ln(1013)/ln(871)-ln(681) //option 3 step 1: .10191391
display 0.5*871*(1+(.10191391/(.10191391-1))) //option 3 step 2: 386.0799 

recode e15  1=25 2=65 3=95 4=125 5=160 6=200 7=240 8=285 9=335 10=395 11=485  ///
		    12=610 13=775 14=971, gen(wage2004) //creating a continuous 2004 earnings variable

*2011
tab qe11, m
display 60/2 //30
display (61+100)/2 //80
display (101+130)/2 //115
display (131+170)/2 //150
display (171+220)/2 //195
display (221+260)/2 //240
display (261+310)/2 //285
display (311+370)/2 //340
display (371+430)/2 //400
display (431+520)/2 //475
display (521+650)/2 //585
display (651+820)/2 //735
display (821+1050)/2 //935
//last category is "1.051 or more per week"; adding 100, I topcode the last category to 1.151

* - removing the influence of inflation 2004-2011 - *

/* Transforming the 2011 to 2004 pound sterling, using the Inflation Calculator of the Bank of England
(http://www.bankofengland.co.uk/education/Pages/resources/inflationtools/calculator/flash/default.aspx#):
30=24;80=63;115=91;150=119;195=155;240=191;285=226;340=270;400=318;475=377;585=464;735=583;935=742;1151=914 */

recode qe11 1=24 2=63 3=91 4=119 5=155 6=191 7=226 8=270 9=318 10=377 11=464 12=583 ///
		    13=742 14=914, gen(wage2011) //creating a continuous 2011 earnings variable

* - combining the 2004 and 2011 wage vars into a single variable - *
generate ewage=wage2011 if nyear==1
replace ewage=wage2004 if nyear==0 & wage2011==.
lab var ewage "Wage"
fre ewage
recode ewage .a=. .c=. .e=.
tab ewage nyear, m //2,758 missings

* - distribution earnings - *
hist ewage
gen lnewage=ln(ewage) //taking natural log of earnings 
lab var lnewage "natural logarithm weekly wage"
hist lnewage
sum ewage lnewage
/* logging earnings does not decrease the variance/skewness; non-logged earnings reasonably normal 
(probably because normal distribution earnings used for making earnings categories); 
decision is to use non-logged earnings; later in robustness checks I show that results 
do not change meaningfully when excluding the last (a) 2 and (b) 4 highest earnings values */

** -- B. Predictors of interest -- **

*gender of employee
/*e1. Are you male or female?*/
fre qe1
recode qe1 (1=0 "Men") (2=1 "Women") (.a=.) (.c=.) (.e=.), gen(efemale)
lab var efemale "Female"
tab efemale nyear, m //1,584 missings

*number of female managers
/*How many male and female employees are in each of the following occupational groups? /managers and senior officials*/
gen zmgr_fem2004=zmng_fft+zmng_fpt //in 2004 asked separately for full-time and part-time employees
replace zmgr_fem=zmgr_fem2004 if nyear==0 & zmgr_fem==. //combining the 2004 and 2011 variable
fre zmgr_fem
recode zmgr_fem .b=. .e=.
la var zmgr_fem "Number of female managers"
tab zmgr_fem nyear, m //684 missings

*number of managers --> firms without managers are to be dropped from the analysis
fre zmgr_tot //2011, 666 cases without managers
fre zmng_tot //2004, 1,297 cases without managers

*proportion of managerial employees that are women, derived by the WERS team
fre nfmprop //note: many more missings than in zmgr_fem because there are almost 2,000 cases without managers (see previous)
replace nfmprop=int(nfmprop*100) //transforming to percentages
lab var nfmprop "Female managers"
recode nfmprop .a=. .b=. .e=.
tab nfmprop nyear, m //2,663 missings
hist nfmprop //distribution share women managers

preserve //distribution excluding the 0s and 100s
keep if nfmprop>0 & nfmprop<100 
hist nfmprop 
restore
/*in robustness checks analyses ran excluding workplaces with (1) 0% female managers, 
(2) 100% female managers, (3) 50% female managers, (4) 0% and 100% female managers,
and (5) 0%, 50% and 100% female managers*/

** -- C. Workplace-level controls -- **

*number of employees
/*Currently how many employees do you have on the payroll at this workplace?*/
replace zallemps=ZALLEMPS if nyear==0 & missing(zallemps) //combining 2011 and 2004 vars
lab var zallemps "Workplace size"
fre zallemps //0 missings
hist zallemps 
gen lnzallemps=ln(zallemps) //addressing skew
lab var lnzallemps "Workplace size"
hist lnzallemps

*proportion female in total employment
drop nfemprop //dropping derived by WERS team (2004 values missing)
gen ztotwom04=ZFEMFULL+ZFEMPRT //2004 variable, asked separately for full- and part-time
replace ztotwom=ztotwom04 if nyear==0 & missing(ztotwom) //combining the 2011 and 2004 values
fre ztotwom //number of female employees

gen float nfemprop=.
replace nfemprop=ztotwom/zallemps
replace nfemprop=.b if ztotwom==.b
replace nfemprop=.e if ztotwom==.e
replace nfemprop=.e if zallemps==.e
lab var nfemprop "Female employees"
lab val nfemprop nitem 
replace nfemprop=int(100*nfemprop) //transforming to percentages
tab nfemprop nyear, m //236 missings
hist nfemprop

*proportion managerial employees of total workforce 
drop nmgrprop //dropping derived by WERS team (2004 values missing)
gen float nmgrprop=.
replace nmgrprop=zmgr_tot/zallemps if nyear==1
replace nmgrprop=zmng_tot/zallemps if nyear==0
replace nmgrprop=.b if zmgr_tot==.b | zmng_tot==.b
replace nmgrprop=.e if zmgr_tot==.e | zallemps==.e
lab var nmgrprop "Share managers"
lab val nmgrprop nitem 
replace nmgrprop=int(100*nmgrprop) //transforming to percentages
tab nmgrprop nyear, m //254 missings
hist nmgrprop //skewed
gen lnnmgrprop=ln(nmgrprop+0.01)
hist lnnmgrprop //also not ideal distribution
//in robustness checks analysis with lnnmgrprop instead of nmgrprop

*industry 
fre nsicod03 
recode nsicod03 .e=., gen(industry)
copydesc nsicod03 industry 
la var industry "Industry"
tab industry nyear, m //10 missings

*legal status of organisation to which workplace belongs 
drop nstatus5 //dropping derived by WERS team (2004 values missing)
replace astatus1=ASTATUS1 if nyear==0 & missing(astatus1)
recode astatus1 (1=1 "Public limited company") (2=2 "Private limited company") ///
		(3/8=3 "Other trading sector") (12=4 "Local/central govt") ///
		(9/11=5 "Other public sector") (.e=.), gen(legalstatus)
la var legalstatus "Legal status"
tab legalstatus nyear, m //0 missings

*foreign ownership

//first create public or private sector variable
drop nprivate //dropping derived by WERS team (2004 values missing)
tab astatus2 nyear, m 
replace astatus2=ASTATUS2 if nyear==0 & missing(astatus2) //adding 2004 values

gen byte nprivate=1 if (astatus1>0 & astatus1<8) & ((astatus2>0 & astatus2<8)|astatus2>=.)
replace nprivate=0 if (astatus1>7 & astatus1<=12) & ((astatus2>7 & astatus2<=12)|astatus2>=.)
replace nprivate=.e if nprivate==. & astatus1==.e
lab var nprivate "Private sector"
tab nprivate nyear, m

//continue onto creating foreign ownership variable
drop nforeign //dropping derived by WERS team (2004 values missing)
tab acontrol nyear, m
replace acontrol=ACONTROL if nyear==0 & missing(acontrol) //adding 2004 values

recode acontrol 4/5=1 1/3=0 .a=. .b=. .e=., ge(nforeign)
replace nforeign=0 if nprivate==0
label var nforeign "Foreign owned"
tab nforeign nyear, m // 303 missings

*age of workplace
tab ahowlong nyear, m
replace ahowlong=AHOWLONG if nyear==0 & missing(ahowlong) //adding 2004 values
la var ahowlong "Age of workplace"

//{If AHOWLONG = DK} Could you estimate how many years this workplace has been in operation, using the categories on this card?
tab ahowest nyear, m
replace ahowest=AHOWEST if nyear==0 & missing(ahowest) //adding 2004 values
tab ahowest nyear, m 

//revising code in mqsetup --> 2004 values missing --> dropping defined vars
drop nage1 nage2 
recode ahowlong (0/4=1 "Less than 5 years") (5/9=2 "5 to 9 years") (10/14=3 "10 to 14 years") ///
		(15/20=4 "15 to 20 years") (21/24=5 "21 to 24 years") (25/999=6 "25 or more years") (.b=.b "Don't know"), ge(nage1)
replace nage1=ahowest if ahowlong==.b
recode nage1 (1=1 "Less than 5 years") (2=2 "5 to 9 years") (3/5=3 "10 to 24 years") (6=4 "25 or more years") (.b=.), ge(workplaceage)
la var workplaceage "Age of workplace"
tab workplaceage nyear, m //164 missings

** -- D. Employee-level controls -- **

*usual working hours including overtime, derived by the WERS team 
/*a4. How many hours do you usually work in your job each week, including overtime or extra hours?*/
fre ehours
replace ehours=80 if ehours>80 & !missing(ehours) //topcoding to 80 as max, 44 cases topcoded
recode ehours .a=. .e=.
la var ehours "Hours worked" 
tab ehours nyear, m //2,315 missings
hist ehours

*tenure
/* a1. How many years in total have you been working at this workplace? */
fre qa1
recode qa1 .a=. .c=., gen(etenure)
copydesc qa1 etenure
la var etenure "Tenure"
tab etenure nyear, m //1,582 missings

*on-the-job training 
/*b3. Apart from health and safety training, how much training have you had during the last 12 months, either paid for or organized by your employer?*/
fre qb3
recode qb3 .a=. .c=. .e=., gen(etraining)
copydesc qb3 etraining
la var etraining "Training"
tab etraining nyear, m //1,689 missings

*commitment, derived by the WERS team
/*c1. To what extent do you agree or disagree with the following statements about working here?*/
fre ecommit //additive organisational commitment scale, based on qc1b, qc1c and qc1d
lab var ecommit "Commitment"
recode ecommit .m=.
tab ecommit nyear, m //3,152 missings
hist ecommit

*union membership, derived by the WERS team
/*d1. Are you a member of a trade union or staff association?*/
recode emember .a=. .c=., gen(eunion)
label var eunion "Union member"
tab eunion nyear, m //1,578 missings

*age, derived by the WERS team
/*e2. How old are you?*/
fre eage
la var eage "Age" 
recode eage .a=. 
tab eage nyear, m //1,578 missings

*partner
/*e3. Which of the following describes your current status?*/
fre qe3
recode qe3 (2=1 "yes") (1 3/4=0 "no"), gen(epartner)
lab var epartner "Partner"
fre e3 //in 2004 the value labels are different but categories and question same
recode e3 4=1 1/3=0, gen(par2)
replace epartner=par2 if nyear==0 & missing(epartner)
recode epartner .a=. .c=. .e=.
tab epartner nyear, m //1,676 missings

*any dependent children, derived by the WERS team
/*e4. How many dependent children do you have, if any, in the following age groups?*/
fre eanydepc
recode eanydepc .a=. .e=., gen(echildren)
lab var echildren "Children"
tab echildren nyear, m //3,066 missings

*education, derived by the WERS team
/*e7. Which, if any, of the following academic, vocational or professional qualifications have you obtained?*/
fre ehiacar //highest academic qualification recoded
recode ehiacar .a=., gen(eedu)
copydesc ehiacar eedu
lab var eedu "Education" 
tab eedu nyear, m //1,675 missings

*employees in managerial occupations - based on SOC 2000 (esocoldb), derived by the WERS team --> to exclude from analysis
fre esocoldb //5,133 (11% of sample)
recode esocoldb .b=. .e=., gen(emng)
lab var emng "Managers, Directors and Senior officials"
tab emng nyear, m //2,383 missings

** -- E. Workplace policies and arrangements -- **

***********************************
* Equality and Diversity
***********************************

* Workplace covered by a strategic plan which covers employee diversity
/*Is this workplace covered by a formal strategic plan which sets out objectives and how they will be achieved?
{if yes} Which of the following issues are covered in the plan? // Employee diversity*/

//derived by the WERS team, but 2004 values missing; dropping and rerunning
drop nstrateg nstrdiv ndivstra 
replace bstrateg=BSTRATEG if nyear==0 & missing(bstrateg) //adding 2004 values
foreach num of numlist 1/8 {
		replace bmanage`num'=BMANAGE`num' if nyear==0 & missing(bmanage`num') 
}

recode bstrateg 1=1 2=0, gen(nstrateg)
replace nstrateg=.a if bstrateg==.a
replace nstrateg=.b if bstrateg==.b
replace nstrateg=.e if bstrateg==.e
label var nstrateg "Workplace covered by formal strategic plan"
ta nstrateg nyear, m

egen nstrdiv=anymatch(bmanag*), values(3)
replace nstrdiv=3 if nstrdiv==1
replace nstrdiv=2 if nstrdiv==0
replace nstrdiv=1 if bstrateg==2
replace nstrdiv=.a if bmanage1==.a
replace nstrdiv=.b if bmanage1==.b
replace nstrdiv=.e if bmanage1==.e&bstrateg==1
label var nstrdiv "Strategic plan covering employee diversity"
ta nstrdiv nyear, m

recode nstrdiv 1 2=0 3=1, gen(ndivstra)
replace ndivstra=.a if bmanage1==.a
replace ndivstra=.b if bmanage1==.b
replace ndivstra=.e if bmanage1==.e&bstrateg==1
label var ndivstra "Diversity strategic plan"
label values ndivstra nyesno
recode ndivstra .b=.
ta ndivstra nyear, m //178 missings

* Special procedures to encourage applications from women and women returnees
/*When filling vacancies, do you have any special procedures to encourage applications from the following groups?
/1) women returning to work after having children /2) women in general*/

//derived by the WERS team, but 2004 values missing; dropping and rerunning
drop nspecwom

tab cspecix1, m //2011 variable, through cspecix9
tab CSPECIA1, m //2004 variable, through CSPECIA7

foreach num of numlist 1/7 { //renaming 2004 variable
		rename CSPECIA`num' cspecia`num'
}

egen nspecwom=anymatch(cspec*),values(1 2)
replace nspecwom=.a if cspecix1==.a|cspecia1==.a
replace nspecwom=.b if cspecix1==.b|cspecia1==.b
replace nspecwom=.e if cspecix1==.e
label var nspecwom "Encourages women applicants"
fre nspecwom
recode nspecwom .b=. .e=.
ta nspecwom nyear, m //126 missings

* Whether monitored recruitment or selection by various protected characteristics
/*Do you monitor recruitment and selection by any of the characteristics on this card? 1) gender*/
fre niprac11 //derived by WERS team
recode niprac11 .a=. .b=. .e=.
la var niprac11 "Monitors recruitment by gender" 
ta niprac11 nyear, m //321 missings

* Whether reviewed recruitment or selection procedures to identify indirect discrimination by various protected characteristics
/*Do you review recruitment and selection procedures to identify indirect discrimination by any of these characteristics? /1) gender*/
fre niprac21 //derived by WERS team
recode niprac21 .a=. .b=. .e=.
la var niprac21 "Reviews recruitment for gender discrimination"
ta niprac21 nyear, m //790 missings

* Whether monitored promotion by various protected characteristics
/*Do you monitor promotions by any of these characteristics? /1) gender*/
fre niprac31 //derived by WERS team
recode niprac31 .a=. .b=. .e=.
la var niprac31 "Monitors promotion by gender"
ta niprac31 nyear, m //655 missings

* Whether reviewed promotion procedures to identify indirect discrimination by various protected characteristics
/*Do you review promotion procedures to identify indirect discrimination by any of these characteristics? / 1) gender*/
fre niprac41 //derived by WERS team
recode niprac41 .a=. .b=. .e=.
la var niprac41 "Reviews promotion for gender discrimination"
ta niprac41 nyear, m //774 missings

* Whether reviewed relative pay rates by various protected characteristics
/*Do you review relative pay rates by any of these characteristics? / 1) gender*/
fre niprac51 //derived by WERS team
recode niprac51 .a=. .b=. .e=.
la var niprac51 "Reviews pay by gender"
ta niprac51 nyear, m //740 missings

***********************************
* Family friendly arrangements 
***********************************

/* Now I'd like to ask you about the different types of flexible working, leave and childcare arrangements 
which some employers provide their employees to help them to balance their work and home lives.
Looking at this card, do you have any of the following working time arrangements for any employees at this workplace?*/ 

* Working at or from home in normal working hours
fre nffhome //derived by WERS team
recode nffhome .a=. .b=. .e=. 
la var nffhome "Home-based working"
ta nffhome nyear, m //38 missings

* Flexi time (where an employee has no set start or finish time but an agreement to work a set number of hours per week or per month) 
fre nffflexi //derived by WERS team
recode nffflexi .a=. .b=. .e=. 
la var nffflexi "Flexi time"
ta nffflexi nyear, m //38 missings

* Job sharing schemes (sharing a full-time job with another employee) 
fre nffjshar //derived by WERS team
recode nffjshar .a=. .b=. .e=. 
la var nffjshar "Job share"
ta nffjshar nyear, m //38 missings

* The ability to reduce working hours (e.g. switching from full-time to parttime employment)
fre nffredhr //derived by WERS team 
recode nffredhr .a=. .b=. .e=.
la var nffredhr "Reduced hours"
ta nffredhr nyear, m //38 missings

* Compressed hours (i.e. working standard hours across fewer days) 
fre nffcompr //derived by WERS team
recode nffcompr .a=. .b=. .e=.
la var nffcompr "Compressed hours"
ta nffcompr nyear, m //38 missings

* Working only during school term times 
fre nffterm //derived by WERS team
recode nffterm .a=. .b=. .e=.
la var nffterm "Term time working"
ta nffterm nyear, m //38 missings

***********************************
* Support for carers
***********************************

/*Looking at this card, are any employees here entitled to any of the following?*/

* Workplace nursery or nursery linked with workplace
fre nnursery //derived by WERS team
recode nnursery .a=. .b=. .e=.
la var nnursery "Nursery places" 
ta nnursery nyear, m //302 missings

* Financial help with child care (e.g. childcare vouchers, loans, repayable contributions to fees for childcare outside the workplace, subsidised places not located at the workplace)
fre nccsubsi //derived by WERS team
recode nccsubsi .a=. .b=. .e=. 
la var nccsubsi "Financial help childcare"
ta nccsubsi nyear, m //302 missings

***********************************
* Summary indicators
***********************************

/*presence equality and diversity policies & practices*/
gen equaldiv=0 
replace equaldiv=1 if ndivstra==1 | nspecwom==1 | niprac11==1 | ///
		niprac21==1 | niprac31==1 | niprac41==1 | niprac51==1
la var equaldiv "Any equality and diversity policy"

/*number equality and diversity policies & practices*/
sort serno time
by serno time: gen nequal=ndivstra+nspecwom+niprac11+niprac21+niprac31+niprac41+niprac51
la var nequal "Number equality and diversity policies"
fre nequal

/*presence flexible work arrangements*/
gen flex=0
replace flex=1 if nffhome==1 | nffflexi==1 | nffjshar==1 | ///
		nffredhr==1 | nffcompr==1 | nffterm==1
la var flex "Any flexible work arrangements" 

/*number flexible work arrangements*/
drop nflex
sort serno time
by serno time: gen nflex=nffhome+nffflexi+nffjshar+nffredhr+nffcompr+nffterm
la var nflex "Number flexible work arrangements"
fre nflex

/*presence support for carers*/
gen care=0
replace care=1 if nnursery==1 | nccsubsi==1 
la var care "Any support for carers" 

/*number support for carers*/
sort serno time
by serno time: gen ncare=nnursery+nccsubsi
la var ncare "Number support for carers" 
fre ncare

** -- F. Pay determination -- **

//derived by the WERS team, but 2004 values missing; dropping and rerunning
drop nfsoc1 nfsoc2 nfsoc3 nfsoc4 nfsoc5 nfsoc6 nfsoc7 nfsoc8 nfsoc9

foreach num of numlist 1/9 { //adding 2004 values, idem below
		replace fsoc`num'=FSOC`num' if nyear==0 & missing(fsoc`num') 
}

foreach num of numlist 1/9 {
		ge nfsoc`num'=fsoc`num'
}

replace nfsoc1=0 if zmgr_tot==0&nyear==1
replace nfsoc1=0 if zmng_tot==0&nyear==0
replace nfsoc2=0 if zpro_tot==0
replace nfsoc3=0 if ztec_tot==0
replace nfsoc4=0 if zadm_tot==0
replace nfsoc5=0 if zskl_tot==0
replace nfsoc6=0 if zper_tot==0
replace nfsoc7=0 if zsal_tot==0
replace nfsoc8=0 if zope_tot==0
replace nfsoc9=0 if zrou_tot==0

* incorporate data from the backcodes in 2011
foreach num of numlist 1/3 9 {
		replace nfsoc`num'=xfsoc`num'2 if xfsoc`num'2<.
		replace nfsoc`num'=xfsoc`num'1 if xfsoc`num'1<.
}

foreach num of numlist 4/8 {
		replace nfsoc`num'=xfsoc`num'1 if xfsoc`num'1<.
}

foreach num of numlist 1/9 {
		recode nfsoc`num' .a=. .b=. .e=. 
}

foreach num of numlist 1/9 {
		ta nfsoc`num' nyear, m
}

label var nfsoc1 "Method of pay determination edited, managers" //467 missings
label var nfsoc2 "Method of pay determination edited, prof" //474 missings
label var nfsoc3 "Method of pay determination edited, ass prof" //513 missings
label var nfsoc4 "Method of pay determination edited, admin" //484 missings
label var nfsoc5 "Method of pay determination edited, skilled trades" //433 missings
label var nfsoc6 "Method of pay determination edited, pers serv" //433 missings
label var nfsoc7 "Method of pay determination edited, sales" //418 missings
label var nfsoc8 "Method of pay determination edited, operatives" //423 missings
label var nfsoc9 "Method of pay determination edited, routine" //593 missings
label values nfsoc* occpay

//which is the largest non-managerial group? 
unab xvars: zpro_tot ztec_tot zadm_tot zskl_tot zper_tot zsal_tot zope_tot zrou_tot

gen which_max = "" 
gen max = 0 

quietly foreach x of local xvars { 
		replace which_max = "`x'" if `x' > max
		replace max = `x' if `x' > max
}

//pay determination taken for largest non-managerial group 
gen paysystem=0
replace paysystem=nfsoc2 if which_max=="zpro_tot" //Professional occupations
replace paysystem=nfsoc3 if which_max=="ztec_tot" //Associate professional and technical occupations
replace paysystem=nfsoc4 if which_max=="zadm_tot" //Administrative and secretarial occupations
replace paysystem=nfsoc5 if which_max=="zskl_tot" //Skilled trades occupations
replace paysystem=nfsoc6 if which_max=="zper_tot" //Caring, leisure and other personal service occupations
replace paysystem=nfsoc7 if which_max=="zsal_tot" //Sales and customer service occupations
replace paysystem=nfsoc8 if which_max=="zope_tot" //Process, plant and machine operatives and drivers
replace paysystem=nfsoc9 if which_max=="zrou_tot" //Routine occupations
lab define pay 0 "none in occupation" 1 "Col Barg multiple employer" 2 "Col Barg org level" ///
		3 "Col Barg wp level" 4 "Set by management org level" 5 "Set by management wp level" ///
		6 "Neg with individuals" 7 "Independent PRB" 8 "Other" 95 "Other specific" 96 "Other vague" 97 "editor unsure"
label value paysystem pay
tab paysystem nyear, m

*==============================================================================*
*    	   	                    3. Analytic sample                             *
*==============================================================================*

/*Table A1. Analytic Sample

The information in the table is derived from the routine below.*/

*selection panel
keep if nseqpan==1 
bysort nyear: distinct serno //7,943 employees in 2004, 7,324 employees in 2011

*excluding "Managers, Directors and Senior officials" 
drop if emng==1 
bysort nyear: distinct serno 

*excluding cases with missing values

	/*missing data on outcome*/
	keep if !missing(ewage) //cases lost: 451
	bysort nyear: distinct serno 
	
	/*missing data on gender employee*/
	keep if !missing(efemale) //cases lost: 45
	bysort nyear: distinct serno 
	
	/*missing data on share female managers*/
	keep if !missing(nfmprop) //cases lost: 775 
	bysort nyear: distinct serno 
	
	/*missing data on employee-level controls*/
	keep if !missing(ehours) & !missing(etenure) & !missing(etraining) & !missing(ecommit) ///
	& !missing(eunion) & !missing(eage) & !missing(epartner) & !missing(echildren) & !missing(eedu) //cases lost: 1,406
	bysort nyear: distinct serno 
	
	/*missing data on workplace-level controls*/
	keep if !missing(lnzallemps) & !missing(nfemprop) & !missing(nmgrprop) & !missing(industry) ///
	& !missing(legalstatus) & !missing(nforeign) & !missing(workplaceage) //cases lost: 105
	bysort nyear: distinct serno 
	
	/*missing data on equality & diversity mediators*/
	keep if !missing(ndivstra) & !missing(nspecwom) & !missing(niprac11) & !missing(niprac21) ///
	& !missing(niprac31) & !missing(niprac41) & !missing(niprac51) //cases lost: 483
	bysort nyear: distinct serno 

	/*missing data on family friendly arrangements mediators*/
	keep if !missing(nffhome) & !missing(nffflexi) & !missing(nffjshar) & !missing(nffredhr) ///
	& !missing(nffcompr) & !missing(nffterm) //cases lost: 0
	bysort nyear: distinct serno 
	
	/*missing data on support for carers mediators*/
	keep if !missing(nnursery) & !missing(nccsubsi) //cases lost: 19 
	bysort nyear: distinct serno 
	
* excluding workplaces that appear in only one wave after dropping of missings

//after dropping missings, how many workplaces in both waves? 
unique nyear, by(serno) gen(unique)
tab unique nyear, m //452 in both waves, 58 only in 2004, 67 only in 2011

by serno nyear, sort: gen nvals = _n == 1 
by serno: replace nvals = sum(nvals)
by serno: replace nvals = nvals[_N] 
tab nvals, m
keep if nvals==2 //cases lost: 1,097 
bysort nyear: distinct serno 

distinct serno //452 workplaces, 9,254 employees --> final sample size

*==============================================================================*
*                              4. Saving data                                  *
*==============================================================================*	
save "$pathp\workingdata", replace //saving data for analysis

**end dofile
log close
